#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio-prettyprint
version:              0.1.1.0
visibility:           public
id:                   rio-prettyprint-0.1.1.0-JBFFsx0hIgMAjI3U16VXgk
key:                  rio-prettyprint-0.1.1.0-JBFFsx0hIgMAjI3U16VXgk
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio-prettyprint#readme
synopsis:             Pretty-printing for RIO
description:          Combine RIO'\''s log capabilities with pretty printing
category:             Development
abi:                  24a6537db171198766f7bf5cf94569fb
exposed:              True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended

hidden-modules:       Paths_rio_prettyprint
import-dirs:          /usr/lib/ghc-8.10.5/site-local/rio-prettyprint-0.1.1.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/rio-prettyprint-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/rio-prettyprint-0.1.1.0
hs-libraries:         HSrio-prettyprint-0.1.1.0-JBFFsx0hIgMAjI3U16VXgk
depends:
    Cabal-3.2.1.0 aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ
    annotated-wl-pprint-0.7.0-LfvIEL94sD0ER9mdrVDak7
    ansi-terminal-0.11-366lZebL4UKAFopo4Q1x1i array-0.5.4.0
    base-4.14.2.0 colour-2.3.5-Kcgb8k1EndZEaiZNG4e3mM mtl-2.2.2
    path-0.8.0-Jmb502JJEg14OSfruVAV7G
    rio-0.1.20.0-HB8itqXT0PyKEg00wpX7Kh text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock

haddock-html:         /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

